@@ -13,12 +13,12 @@ our @EXPORT = qw/
   forkmap
 /;
 
-our $VERSION = '0.2304';
+our $VERSION = '0.2305';
 
 my $MAX_PROCS = 4;
 my $TIMEOUT = 0;
 my $IPC = 1;
-my $TEMPFILE_DIR = '/tmp';
+my $TEMPFILE_DIR;
 
 sub forkmap_settings {
   my %opts = @_;
@@ -201,8 +201,8 @@ The function evaluates code blocks concurrently, with an optional callback.
   forkmap_settings(
     TIMEOUT => $seconds,  # forked proc timeout in seconds (default: 0 = no timeout)
     MAX_PROCS => $n,  # maximum concurrent forked procs (default: 4)
-    IPC => 0,  # enable return data via tempfiles (default: 1)
-    TEMPFILE_DIR => $dir  # directory to store tempfiles (default: '/tmp')
+    IPC => $ipc,  # enable return data via tempfiles (default: 1)
+    TEMPFILE_DIR => $dir  # directory to store tempfiles (default: File::Temp default)
   );
 
 Modify runtime parameters for C<forkmap>.
@@ -219,7 +219,7 @@ Time in seconds to allow each process to run before killed (default: 0 = no time
 
 =item * IPC
 
-Enable return data (default: 1).
+Enable = 1 or disable = 0 return data (default: 1).
 
 If enabled, the return value of the BLOCK must be a scalar.
 The value is then sent via temporary files.
@@ -228,7 +228,7 @@ inside the code block (for example using JSON or Storable).
 
 =item * TEMPFILE_DIR
 
-Directory to store tempfiles (default: '/tmp').
+Directory to store tempfiles (default: File::Temp default).
 
 =back
 
